@@ -16,7 +16,7 @@ latex_str <- function(x, ft.align = "center",
   dat <- get_text_data(x, linespacing_df)
 
   # hhlines and vborders ----
-  augment_borders(properties_df)
+  properties_df <- augment_borders(properties_df)
 
   # cell background color -----
   properties_df[, c("background_color") := list(
@@ -85,12 +85,7 @@ latex_str <- function(x, ft.align = "center",
   txt_data[, c("txt") := list(paste0(.SD$txt, " \\\\"))]
   setorderv(txt_data, c("part", "ft_row_id"))
 
-  if (any(!cell_properties_df$background_color %in% "")) {
-    # need hhline as cline does not work when there is a background_color
-    hhline_data <- extract_hhline_bottom(cell_properties_df)
-  } else {
-    hhline_data <- extract_cline(cell_properties_df)
-  }
+  hhline_data <- extract_hhline_bottom(cell_properties_df)
 
   hhline_top_data <- augment_top_borders(cell_properties_df)
   txt_data <- merge(txt_data, hhline_top_data, by = c("part", "ft_row_id"), all.x = TRUE, all.y = TRUE)
@@ -251,22 +246,83 @@ augment_top_borders <- function(properties_df) {
   hhline_top_data
 }
 
+#' @importFrom data.table copy
+#' @noRd
+#' @title make border top and bottom restructured
+#' as hline. If two borders overlap, the largest is
+#' choosen.
+as_border_latex <- function(x){
+  properties_df <- copy(x)
+  col_id_levels <- levels(properties_df$col_id)
+
+  top <- dcast(properties_df, part + ft_row_id ~ col_id, value.var = "border.width.top")
+  bottom <- dcast(properties_df, part + ft_row_id ~ col_id, value.var = "border.width.bottom")
+  top_mat <- as.matrix(top[, 3:ncol(top)])
+  bot_mat <- as.matrix(bottom[, 3:ncol(top)])
+
+  new_row_n <- nrow(top) + 1
+
+  if(new_row_n > 2){ # at least 3 rows
+
+    hlinemat <- matrix(0.0, nrow = new_row_n, ncol = ncol(top_mat))
+
+    hlinemat[1,] <- top_mat[1, , drop = FALSE]
+    hlinemat[nrow(hlinemat),] <- bot_mat[nrow(bot_mat),, drop = FALSE]
+    hlinemat[setdiff(seq_len(new_row_n), c(1, new_row_n)),] <- pmax(bot_mat[-nrow(bot_mat),, drop = FALSE], top_mat[-1,, drop = FALSE])
+
+    # now lets replace values
+    bottom[, 3:ncol(top)] <- as.data.table(hlinemat[-1,])
+    top[1, 3:ncol(top)] <- as.data.table(hlinemat[1,, drop = FALSE])
+    top[2:nrow(top), 3:ncol(top)] <- 0.0
+
+    top <- melt(top,
+                id.vars = c("part", "ft_row_id"),
+                variable.name = "col_id",
+                value.name = "border.width.top",
+                variable.factor = FALSE)
+    top$col_id <- factor(top$col_id, levels = col_id_levels)
+    bottom <- melt(bottom,
+                   id.vars = c("part", "ft_row_id"),
+                   variable.name = "col_id",
+                   value.name = "border.width.bottom",
+                   variable.factor = FALSE)
+    bottom$col_id <- factor(bottom$col_id, levels = col_id_levels)
+
+    properties_df$border.width.bottom <- NULL
+    properties_df$border.width.top <- NULL
+
+    properties_df <- merge(
+      x = properties_df,
+      y = top,
+      by = c("part", "ft_row_id", "col_id"))
+    properties_df <- merge(
+      x = properties_df,
+      y = bottom,
+      by = c("part", "ft_row_id", "col_id"))
+  }
+
+  properties_df
+}
+
+
 augment_borders <- function(properties_df) {
   stopifnot(is.data.table(properties_df))
   # hhlines and vborders ----
+
+  properties_df <- as_border_latex(properties_df)
   properties_df[, c("vborder_left", "vborder_right", "hhlines_bottom", "hhlines_top") :=
     list(
       latex_vborder(w = .SD$border.width.left, cols = .SD$border.color.left),
-      fcase((as.integer(.SD$col_id) + .SD$rowspan) == (nlevels(.SD$col_id) + 1L),
+      fcase(
+        (as.integer(.SD$col_id) + .SD$rowspan) == (nlevels(.SD$col_id) + 1L),
         latex_vborder(w = .SD$border.width.right, cols = .SD$border.color.right),
         default = ""
       ),
       latex_hhline(w = .SD$border.width.bottom, cols = .SD$border.color.bottom),
-      fcase(.SD$ft_row_id %in% 1 &
-              as.integer(.SD$part) == min(as.integer(.SD$part)),
-      latex_hhline(w = .SD$border.width.top, cols = .SD$border.color.top),
-      default = ""
-      )
+      fcase(
+        .SD$ft_row_id %in% 1 & as.integer(.SD$part) == min(as.integer(.SD$part)),
+        latex_hhline(w = .SD$border.width.top, cols = .SD$border.color.top),
+        default = "")
     )]
   void_merged_colspan <- function(hhline, colspan) {
     ifelse(c(colspan[-1], 1) < 1, "~", hhline)
@@ -301,17 +357,6 @@ latex_hhline <- function(w, cols, digits = 0) {
   z[w < .001 | is_transparent] <- "~"
   z
 }
-latex_cline <- function(w, cols, from, to) {
-  size <- format_double(w, digits = 1)
-  is_transparent <- colalpha(cols) < 1
-  cols <- colcode0(cols)
-  z <- sprintf(
-    "\\docline{%spt}{%s}{%s}",
-    size, cols, paste(from, to, sep = "-")
-  )
-  z[w < .001 | is_transparent] <- ""
-  z
-}
 
 extract_hhline_bottom <- function(cell_data) {
   was_dt <- is.data.table(cell_data)
@@ -338,38 +383,6 @@ extract_hhline_bottom <- function(cell_data) {
   hhline
 }
 
-extract_cline <- function(df) {
-  border_bottom <- df[, c(
-    "part", "col_id", "ft_row_id", "colspan",
-    "border.width.bottom", "border.color.bottom", "border.style.bottom"
-  )]
-  setorderv(border_bottom, cols = c("part", "ft_row_id", "col_id"))
-  border_bottom[border_bottom$colspan < 1, c("border.width.bottom") := list(0), ]
-  border_bottom[, c("border_uid") :=
-    list(
-      rleid(
-        .SD$border.width.bottom,
-        .SD$border.color.bottom,
-        .SD$border.style.bottom
-      )
-    ), by = c("part", "ft_row_id")]
-
-  border_bottom <- border_bottom[, list(
-    cline = latex_cline(
-      w = head(.SD$border.width.bottom, n = 1),
-      cols = head(.SD$border.color.bottom, n = 1),
-      from = min(as.integer(.SD$col_id)),
-      to = max(as.integer(.SD$col_id))
-    )
-  ), by = c("part", "ft_row_id", "border_uid")]
-  border_bottom <- border_bottom[, list(
-    hhline = paste(.SD$cline, collapse = "")
-  ), by = c("part", "ft_row_id")]
-
-  setDF(border_bottom)
-  border_bottom
-}
-
 cline_cmd <- paste0(
   "\\providecommand{\\docline}[3]{",
   "\\noalign{\\global\\setlength{\\arrayrulewidth}{#1}}",
@@ -503,6 +516,18 @@ latex_caption <- function(x, bookdown) {
   }
   caption <- ""
   if (!is.null(caption_label)) {
+
+    if (requireNamespace("commonmark", quietly = TRUE)) {
+      gmatch <- gregexpr(pattern = "\\$[^\\$]+\\$", caption_label)
+      equations <- regmatches(caption_label, gmatch)[[1]]
+      names(equations) <- sprintf("EQUATIONN%.0f", seq_along(equations))
+      regmatches(caption_label, gmatch) <- list(names(equations))
+      caption_label <- commonmark::markdown_latex(caption_label)
+      for(eq in names(equations)){
+        caption_label <- gsub(eq, equations[eq], caption_label)
+      }
+    }
+
     caption <- paste0(
       "\\caption{",
       caption_label, "}",
