@@ -517,6 +517,7 @@ align <- function(x, i = NULL, j = NULL, align = "left",
 #' @param j columns selection
 #' @param part partname of the table (one of 'all', 'body', 'header', 'footer')
 #' @param space space between lines of text, 1 is single line spacing, 2 is double line spacing.
+#' @param unit unit for space, one of "in", "cm", "mm".
 #' @family sugar functions for table style
 #' @examples
 #' ft <- flextable(head(mtcars)[,3:6])
@@ -526,7 +527,9 @@ align <- function(x, i = NULL, j = NULL, align = "left",
 #' @section Illustrations:
 #'
 #' \if{html}{\figure{fig_line_spacing_1.png}{options: width=70\%}}
-line_spacing <- function(x, i = NULL, j = NULL, space = 1, part = "body" ){
+line_spacing <- function(x, i = NULL, j = NULL, space = 1, part = "body", unit = "in" ){
+
+  space <- convin(unit = unit, x = space)
 
   if( !inherits(x, "flextable") ) stop("align supports only flextable objects.")
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
